==> haskell-scientific-0.3.5.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-scientific.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: scientific
version: 0.3.5.3
id: scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
key: scientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
license: BSD3
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/scientific
synopsis: Numbers represented using scientific notation
description:
    "Data.Scientific" provides the number type '\''Scientific'\''. Scientific numbers are
    arbitrary precision and space efficient. They are represented using
    <http://en.wikipedia.org/wiki/Scientific_notation scientific notation>.
    The implementation uses a coefficient @c :: '\''Integer'\''@ and a base-10 exponent
    @e :: '\''Int'\''@. A scientific number corresponds to the
    '\''Fractional'\'' number: @'\''fromInteger'\'' c * 10 '\''^^'\'' e@.
    .
    Note that since we'\''re using an '\''Int'\'' to represent the exponent these numbers
    aren'\''t truly arbitrary precision. I intend to change the type of the exponent
    to '\''Integer'\'' in a future release.
    .
    The main application of '\''Scientific'\'' is to be used as the target of parsing
    arbitrary precision numbers coming from an untrusted source. The advantages
    over using '\''Rational'\'' for this are that:
    .
    * A '\''Scientific'\'' is more efficient to construct. Rational numbers need to be
    constructed using '\''%'\'' which has to compute the '\''gcd'\'' of the '\''numerator'\'' and
    '\''denominator'\''.
    .
    * '\''Scientific'\'' is safe against numbers with huge exponents. For example:
    @1e1000000000 :: '\''Rational'\''@ will fill up all space and crash your
    program. Scientific works as expected:
    .
    >>> read "1e1000000000" :: Scientific
    1.0e1000000000
    .
    * Also, the space usage of converting scientific numbers with huge exponents to
    @'\''Integral'\''s@ (like: '\''Int'\'') or @'\''RealFloat'\''s@ (like: '\''Double'\'' or '\''Float'\'')
    will always be bounded by the target type.
category: Data
author: Bas van Dijk
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.Builder.Scientific Data.Scientific
    Data.Text.Lazy.Builder.Scientific
hidden-modules: GHC.Integer.Compat Utils
abi: 490d099f5e386f4f486a599d7d1e6789
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/scientific-0.3.5.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/scientific-0.3.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/scientific-0.3.5.3
hs-libraries: HSscientific-0.3.5.3-HgtwFQ4gEJZ599U6d6bYAG
depends:
    base-4.10.1.0 integer-logarithms-1.0.2.1-2a6l3Ge7uAMKtkov70g6We
    deepseq-1.4.3.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo containers-0.5.10.2
    binary-0.8.5.1 bytestring-0.10.8.2 integer-gmp-1.0.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             integer-logarithms-1.0.2.1-2a6l3Ge7uAMKtkov70g6We=c9ed9a21f6bbfcdbf30f6edb9eaef994
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc=c4d94c55b0f818097c80d373d8b40893
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=c6749b6f9516519305c703393b0c0693
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             integer-gmp-1.0.1.0=9c3d9ccbdd7bdea277cdecf74e14db2b
haddock-interfaces: /usr/share/doc/haskell-scientific/html/scientific.haddock
haddock-html: /usr/share/doc/haskell-scientific/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-scientific-0.3.6.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-scientific.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: scientific
version: 0.3.6.2
id: scientific-0.3.6.2-2MF9INjgKxiGvbC0MBb5FD
key: scientific-0.3.6.2-2MF9INjgKxiGvbC0MBb5FD
license: BSD3
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/scientific
synopsis: Numbers represented using scientific notation
description:
    "Data.Scientific" provides the number type '\''Scientific'\''. Scientific numbers are
    arbitrary precision and space efficient. They are represented using
    <http://en.wikipedia.org/wiki/Scientific_notation scientific notation>.
    The implementation uses a coefficient @c :: '\''Integer'\''@ and a base-10 exponent
    @e :: '\''Int'\''@. A scientific number corresponds to the
    '\''Fractional'\'' number: @'\''fromInteger'\'' c * 10 '\''^^'\'' e@.
    .
    Note that since we'\''re using an '\''Int'\'' to represent the exponent these numbers
    aren'\''t truly arbitrary precision. I intend to change the type of the exponent
    to '\''Integer'\'' in a future release.
    .
    The main application of '\''Scientific'\'' is to be used as the target of parsing
    arbitrary precision numbers coming from an untrusted source. The advantages
    over using '\''Rational'\'' for this are that:
    .
    * A '\''Scientific'\'' is more efficient to construct. Rational numbers need to be
    constructed using '\''%'\'' which has to compute the '\''gcd'\'' of the '\''numerator'\'' and
    '\''denominator'\''.
    .
    * '\''Scientific'\'' is safe against numbers with huge exponents. For example:
    @1e1000000000 :: '\''Rational'\''@ will fill up all space and crash your
    program. Scientific works as expected:
    .
    >>> read "1e1000000000" :: Scientific
    1.0e1000000000
    .
    * Also, the space usage of converting scientific numbers with huge exponents to
    @'\''Integral'\''s@ (like: '\''Int'\'') or @'\''RealFloat'\''s@ (like: '\''Double'\'' or '\''Float'\'')
    will always be bounded by the target type.
category: Data
author: Bas van Dijk
exposed: True
indefinite: False
exposed-modules:
    Data.ByteString.Builder.Scientific Data.Scientific
    Data.Text.Lazy.Builder.Scientific
hidden-modules: GHC.Integer.Compat Utils
abi: b926dd2e2fb0b7b9106a4de9722f1bf6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/scientific-0.3.6.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/scientific-0.3.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/scientific-0.3.6.2
hs-libraries: HSscientific-0.3.6.2-2MF9INjgKxiGvbC0MBb5FD
depends:
    base-4.10.1.0 integer-logarithms-1.0.2.1-2a6l3Ge7uAMKtkov70g6We
    deepseq-1.4.3.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc
    primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo containers-0.5.10.2
    binary-0.8.5.1 bytestring-0.10.8.2 integer-gmp-1.0.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             integer-logarithms-1.0.2.1-2a6l3Ge7uAMKtkov70g6We=c9ed9a21f6bbfcdbf30f6edb9eaef994
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             hashable-1.2.7.0-LNZUQuuTAXDAhrIFkkeiYc=c4d94c55b0f818097c80d373d8b40893
             primitive-0.6.3.0-CXy1O9sQYlI58rn9KQkFyo=c6749b6f9516519305c703393b0c0693
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             binary-0.8.5.1=efb65bc450356b9ea572733928ffb43f
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             integer-gmp-1.0.1.0=9c3d9ccbdd7bdea277cdecf74e14db2b
haddock-interfaces: /usr/share/doc/haskell-scientific/html/scientific.haddock
haddock-html: /usr/share/doc/haskell-scientific/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
